@@ -14,11 +14,13 @@ from robust.angular import (Orientation,
 
 from sect.hints import (Contour,
                         Point,
-                        Segment,
-                        Triangle)
+                        Segment)
+from .hints import BoundingBox
 
 Domain = TypeVar('Domain')
 
+flatten = chain.from_iterable
+
 
 def to_convex_hull(points: Sequence[Point]) -> List[Point]:
     points = sorted(points)
@@ -40,17 +42,13 @@ def _to_sub_hull(points: Iterable[Point]) -> List[Point]:
     return result
 
 
-flatten = chain.from_iterable
-
-
-def normalize_triangle(triangle: Triangle) -> Triangle:
-    min_index = min(range(len(triangle)),
-                    key=triangle.__getitem__)
-    triangle = triangle[min_index:] + triangle[:min_index]
-    if orientation(triangle[-1], triangle[0],
-                   triangle[1]) is Orientation.COUNTERCLOCKWISE:
-        triangle = triangle[:1] + triangle[1:][::-1]
-    return triangle
+def normalize_contour(contour: Contour) -> Contour:
+    min_index = arg_min(contour)
+    contour = contour[min_index:] + contour[:min_index]
+    if orientation(contour[-1], contour[0],
+                   contour[1]) is Orientation.COUNTERCLOCKWISE:
+        contour = contour[:1] + contour[1:][::-1]
+    return contour
 
 
 def contour_to_segments(contour: Contour) -> List[Segment]:
@@ -58,6 +56,17 @@ def contour_to_segments(contour: Contour) -> List[Segment]:
             for index in range(len(contour))]
 
 
+def to_contour_orientation(contour: Contour) -> Orientation:
+    index = arg_min(contour)
+    return orientation(contour[index], contour[index - 1],
+                       contour[(index + 1) % len(contour)])
+
+
+def arg_min(sequence: Sequence[Domain]) -> int:
+    return min(range(len(sequence)),
+               key=sequence.__getitem__)
+
+
 to_unique_objects = (OrderedDict
                      if sys.version_info < (3, 6)
                      else dict).fromkeys
@@ -66,7 +75,7 @@ to_unique_objects = (OrderedDict
 def coin_change(amount: int, denominations: Iterable[int]) -> List[int]:
     denominations = red_black.tree(*denominations)
     result = []
-    poppers = cycle((red_black.Tree.popmax, red_black.Tree.popmax))
+    poppers = cycle((red_black.Tree.popmax, red_black.Tree.popmin))
     while amount and denominations:
         denomination = next(poppers)(denominations)
         denomination_count, amount = divmod(amount, denomination)
@@ -86,3 +95,13 @@ def pairwise(iterable: Iterable[Domain]) -> Iterable[Tuple[Domain, Domain]]:
     for next_element in iterator:
         yield element, next_element
         element = next_element
+
+
+def points_to_bounding_box(points: Iterable[Point]) -> BoundingBox:
+    points = iter(points)
+    first_point = next(points)
+    min_x, min_y = max_x, max_y = first_point
+    for x, y in points:
+        min_x, max_x = min(min_x, x), max(max_x, x)
+        min_y, max_y = min(min_y, y), max(max_y, y)
+    return min_x, min_y, max_x, max_y
